@@ -10,7 +10,7 @@ def find_cell_text(expected_id):
     Returns:
         int: Chỉ mục của ô có ID mong đợi.
     """
-    indexs = []
+    texts = []
     # Get a reference to the current InteractiveShell object
     shell = IPython.get_ipython()
 
@@ -22,7 +22,10 @@ def find_cell_text(expected_id):
             if line.startswith('#__cell_id__: '):
                 cell_id = line.strip()[len('#__cell_id__: '):]
                 if cell_id == expected_id:
-                    return input_text
+                    texts.append(input_text)
+                    break
+    if len(texts):
+        return texts[-1]
     return -1
 
 
